<?php
// This is a simple example program that connects to an IRC server
// using the sep93irc class and:
//
// - keeps the connection alive
// - joins the specified channel
// - echos what it receives from the server
// - disconnect if it sees "sep93bot: quit" in the channel
// - refuses to disconnect if "quit" is privately messaged

require("conf/config_db.php");
require("conf/config_irc.php");
require("includes/class.db_pdo.php");

$db = new db();
$db->connect($db_host, $db_user, $db_pass, $db_name);

require("sep93db.class.php");
$sep93db = new sep93db($db);

require("sep93irc.class.php");
$irc = new sep93IRC();
$irc_connection = $irc->connect($server, $port, $pass, $nick);

$wait_time = 2; $msg_per_wait_time = 1; // rate limit, 1 message every 2 seconds

if($irc_connection) {

	stream_set_blocking($irc_connection, false);
	$current_rules = $sep93db->getCurrentRules();

	// TODO: get this from a table of active bots?
	$identifier = "7";

	$irc_server_ready = false;

	while($input = trim(fgets($irc_connection)) or true) {
		if(empty($input) and $irc_server_ready) {
			
			if($queued_messages = $sep93db->getQueuedMessages($identifier, $msg_per_wait_time)) {
				foreach($queued_messages as $qm) {
					//TODO: support multiple send_to destinations
					//TODO: check we're in the relevant channel (send_to)
					//TODO: don't send messages older than 24 hours
					$irc->say($qm['send_to'], $qm['message']);
					$sep93db->markQueueSent($qm['id']);
				}
				sleep($wait_time);
			}
				
		} else {

			print $input."\n";
			$sep93db->saveLog($input, $identifier);
			flush();

		stream_set_timeout($irc_connection, 3600);

		// handle the PING/PONG keepalive aspect of IRC (don't log/output)
		if(preg_match("|^PING :(.*)$|i", $input, $matches)) {
			//echo "[ SERVER PONG {$matches[1]} ]\n";
			$irc->keepalive($matches[1]);
			continue;
		}


		// does server send the 'completed login' code (266)
		if(strpos($input, "266")) {
			$irc_server_ready = true;
			if(empty($irc->current_channels[$channel]) and !empty($channel)) {
				$irc->join_channel($channel);
			}
		}

		// handle names output (to update channel list)
		// TODO: is there a limit to the number of names we can handle?
		if(strpos($input, "353")) {
			$irc->set_channel_names_list($input);
		}


		// listen to channel messages
		if(preg_match("~$irc->chan_regex~", $input, $match)) {
			if($msg_info = $irc->parseMessage($match)) {
				foreach($current_rules as $rule) {
					$found_rule = $irc->processRule($rule, $msg_info);
					if($found_rule)
						continue;
				}

				// saved outside of db rules
				if($msg_info['msg'] == "$nick: rehash") {
					$current_rules = $sep93db->getCurrentRules();
					$irc->say($msg_info['source'], "Rehashed");
				}
			}
		}
		}
	}

} else {
	echo "Error #".$irc->error_num.", ".$irc->error_string."\n";
}
