<?php

// helper functions for sep93IRC database stuff
// September 2018, nvm
//

class sep93db {


	function __construct($db) {
		$this->conn = $db;
	}

	function saveLog($input, $identifier) {
		$sql = "insert into server_log set system_time=now(), raw_log = :raw_log, identifier = :identifier";
		$vars[":raw_log"] = $input;
		$vars[":identifier"] = $identifier;
		$this->conn->db_link->prepare($sql)->execute(["raw_log"=>$input, "identifier"=>$identifier]);
	}
	
	function getCurrentRules() {
		$sql = "select * from rules where active=1 order by priority desc, length(trigger_text) desc";
		$stmt = $this->conn->select($sql);
		$data = $stmt->fetchAll(PDO::FETCH_ASSOC);
		return $data;
	}

	function q2send($data) {
		if(empty($data['message']) or empty($data['send_to']))
			return false;

		$sql = "insert into send_queue set send_to = ?, message = ?, priority = ?, sent = 0, queue_time = now(), identifier = ?";
		if(empty($data['priority']))
			$data['priority'] = 0;
		$stmt = $this->conn->db_link->prepare($sql)->execute([$data['send_to'], $data['message'], $data['priority'], $data['identifier']]);
		return $stmt;

	}

	function getQueuedMessages($identifier, $msg_per_second) {
		$sql = "select * from send_queue where identifier = :identifier and sent = 0 order by priority desc limit :limit";
		$stmt = $this->conn->db_link->prepare($sql);
		$stmt->bindParam(":limit", intval($msg_per_second), PDO::PARAM_INT);
		$stmt->bindParam(":identifier", intval($identifier), PDO::PARAM_INT);
		$stmt->execute();
		$data = $stmt->fetchAll();
		return $data;
	}

	function deleteQueuedMessages($identifier) {
		$sql = "delete from send_queue where identifier = ?";
		$stmt = $this->conn->db_link->prepare($sql)->execute([$identifier]);
		return $stmt;
	}

	function howManySentRecently($seconds = 2) {
		$time = date("Y-m-d H:i:s", strtotime("-$seconds seconds"));
		$sql = "select count(id) from send_queue where sent_time >= ?";
		$stmt = $this->conn->db_link->prepare($sql)->execute([$time]);
		return $stmt->fetchColumn();
	}

	function markQueueSent($msg_id) {
		$sql = "update send_queue set sent=1, sent_time=now() where id = ?";
		$stmt = $this->conn->db_link->prepare($sql)->execute([$msg_id]);
		return $stmt;
	}


	// takes whatever string is piped to it, returns a recipient list
	// and a trimmed message
	function splitRawInput($data, $default_send_channel) {
		$valid_chars = array("#", "@");
		$original_string = trim($data);
		$recipients = null;
		$lines = explode("\n", $original_string);
		
		if(is_array($lines)) {
		foreach($lines as $string) {
			// we've just received a single word
			if(strpos($string, " ") === false) {
				$recipients[] = $default_send_channel;
				$message = $string;
			} else {
				// find the first character of the message
				// to determine if its routing info (send_to)
				// or just a message
				$first_word = substr($string, 0, strpos($string, " "));
				$first_char = substr($first_word, 0, 1);
				if(in_array($first_char, $valid_chars)) {
					$message = trim(substr($string, strpos($string, " ")));
				} else {
					$first_word = $default_send_channel;
					$message = $string;
				}

				if(strpos($first_word, ",") === false) {
					$recipients[] = $first_word;
				} else {
					$recipients = explode(",", $first_word);
				}

				// strip out @ signs from usernames
				foreach($recipients as $k=>$v) {
					if(substr($v, 0, 1) == "@")
						$recipients[$k] = substr($v, 1);
				}
			}
		}
		$output['recipients'] = $recipients;
		$output['message'] = $message;
		return $output;
		}
		return false;

	}

}
